/*
:Author: Christian Dywan
:Contact: christian@twotoasts.de
:Copyright: This file is licensed under the terms of the expat license, see the file EXPAT.

Stylesheet for Midori's documentation based on a version of Enrico Troeger.
*/

@media screen {

    html, body {
        width: 100% !important;
        height: 100% !important;
        margin: 0 !important;
        padding: 0 !important;
    }

    * {
        background: #f6fff3 !important;
        color: #404040 !important;
        font-size: 14pt !important;
        font-family: serif !important;
        text-align: justify !important;
        line-height: 1.4em !important;
        word-spacing: 0.4mm !important;
        letter-spacing: 0.2mm !important;
        -webkit-column-count: auto !important;
        -webkit-column-width: auto !important;
        -webkit-box-shadow: none !important;
        width: auto !important;
        word-wrap: break-word !important;
    }

    div, p {
        padding: 5pt !important;
    }

    li {
        padding-left: 5pt !important;
    }

    img, *[accesskey], form *, form, iframe,
    *[id^=navigation], *[id$=navigation], *[id*=navigation], .collapsed, .expanded {
        display: none !important
    }

    /* FIXME: we want "images bigger than 50px here" */
    img[width] {
        display: inline !important
    }

    :link, :link * {
        color: #013100 !important;
        text-decoration: underline !important;
    }

    :visited, :visited * {
        color: #7E558E !important;
        text-decoration: underline !important;
    }

    a:hover {
        text-decoration: none !important;
    }

    h1, h2, h3 {
        font-family: serif !important;
        color: #002a00 !important;
    }

    h1 {
        border-top: 1px dotted;
        margin-top: 2em;
    }

    h1.title {
        text-align: left }

    h2 {
        margin-top: 30px;
    }

    h2.subtitle {
        text-align: left }

    h3 {
        padding-left: 3px;
    }

    blockquote, pre {
        border: 1px solid;
        padding: 0.4em;
    }

    blockquote {
        font-family: sans-serif;
        background-color: #DBEDD5;
        border: 1px dotted;
        border-left: 4px solid;
        border-color: #9FD98C;
    }

    pre {
        background-color: #deefd4;
        border: 1px dotted;
        border-left: 4px solid;
        border-color: #9acb7d;
    }

    tt, pre, code {
        color: #002a00;
    }

    table {
        border: 1px solid #9acb7f;
    }

    th {
        border: none;
        background-color: #9acb7d;
    }

    tr:nth-child(even) {
        background-color: #d3eac6;
    }

    td {
        border: none;
    }

    .docinfo-name {
        color: #002a00;
    }

    p.admonition-title {
        color: #990000;
        font-weight: bold;
    }

    div.note {
        margin: 1em 3em;
        padding: 0em;
    }

    dt {
        font-style: italic;
    }

}
